//
//  AMSDKMediaDevice.h
//  AliMeetingSDK
//
//  Created by xuanzhen.zjw on 2019/8/15.
//  Copyright © 2019 Alibaba. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

//! 会议设备类型
typedef NS_ENUM(NSInteger, AMSDKMediaDeviceType) {
    //! 视频输入设备
    AMSDKMediaDeviceType_VIDEO_INPUT  =  0,
    //! 音频输出设备
    AMSDKMediaDeviceType_AUDIO_OUTPUT =  1,
    //! 音频输入设备
    AMSDKMediaDeviceType_AUDIO_INPUT  =  2
};

//! 设备来源
typedef NS_ENUM(NSInteger, AMSDKMediaDeviceTransportType) {
    //! 内置设备
    AMSDKMediaDeviceTransportType_BUILT_IN      =    0,
    //! USB设备
    AMSDKMediaDeviceTransportType_USB           =    1,
    //! 蓝牙设备
    AMSDKMediaDeviceTransportType_BLUETOOTH     =    2,
    //! AVB设备
    AMSDKMediaDeviceTransportType_AVB           =    3,
    //! Thunderbolt设备
    AMSDKMediaDeviceTransportType_THUNDER_BOLT  =    4,
    //! AirPlay设备
    AMSDKMediaDeviceTransportType_AIR_PLAY      =    5,
    //! 耳机
    AMSDKMediaDeviceTransportType_HEAD_PHONES   =    6
};

//! 相机设备
typedef NS_ENUM(NSInteger, AMSDKCameraDeviceFacing) {
    //! 未指定
    AMSDKCameraDeviceFacingUnspecified      =   0,
    //! 后置摄像头
    AMSDKCameraDeviceFacingBack             =   1,
    //! 前置摄像头
    AMSDKCameraDeviceFacingFront            =   2,
};

//! 音频输出设备
typedef NS_ENUM(NSInteger, AMSDKAudioOutputDevicePort) {
    //! 未指定
    AMSDKAudioOutputDevicePortUnspecified   =   0,
    //! 扬声器
    AMSDKAudioOutputDevicePortSpeaker       =   1,
    //! 听筒
    AMSDKAudioOutputDevicePortReceiver      =   2
};

#pragma mark - AMSDKMediaDevice

//! 媒体设备
@interface AMSDKMediaDevice : NSObject

//! 设备ID
@property (nonatomic, strong, readonly) NSString *deviceId;

//! 设备名称
@property (nonatomic, strong, readonly) NSString *deviceName;

//! 设备类型，输入输出
@property (nonatomic, assign, readonly) AMSDKMediaDeviceType deviceType;

//! 设备来源 (内建、USB、蓝牙等)
@property (nonatomic, assign, readonly) AMSDKMediaDeviceTransportType transportType;

#pragma mark - 注意：下列初始化方法不可用

+ (instancetype)new NS_UNAVAILABLE;

- (instancetype)init NS_UNAVAILABLE;

@end

#pragma mark - AMSDKCameraDevice

//! 相机设备
@interface AMSDKCameraDevice : AMSDKMediaDevice

//! 设备类型，见@AMSDKCameraDeviceFacing
@property (nonatomic, assign, readonly) AMSDKCameraDeviceFacing facing;

@end

#pragma mark - AMSDKAudioOutputDevice

//! 音频输出设备
@interface AMSDKAudioOutputDevice : AMSDKMediaDevice

//！ 输出设备类型，见@AMSDKAudioOutputDevicePort
@property (nonatomic, assign, readonly) AMSDKAudioOutputDevicePort outputPort;

@end

NS_ASSUME_NONNULL_END
